#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IS_GTZ_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IS_GTZ_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/is_gtz.hpp>

#endif
